@@ -17,15 +17,20 @@
   +----------------------------------------------------------------------+
 */
 
-/* $Id: memcache_binary_protocol.c 310129 2011-04-11 04:44:27Z hradtke $ */
+/* $Id: memcache_binary_protocol.c 326387 2012-06-30 17:41:36Z ab $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#ifdef PHP_WIN32
+#include <win32/php_stdint.h>
+#include <winsock2.h>
+#else
 #include <stdint.h>
 #include <arpa/inet.h>
 #include <netinet/in.h>
+#endif
 #include "memcache_pool.h"
 #include "ext/standard/php_smart_str.h"
 
