@@ -17,7 +17,7 @@
   +----------------------------------------------------------------------+
 */
 
-/* $Id: memcache_pool.h 310129 2011-04-11 04:44:27Z hradtke $ */
+/* $Id: memcache_pool.h 326387 2012-06-30 17:41:36Z ab $ */
 
 #ifndef MEMCACHE_POOL_H
 #define MEMCACHE_POOL_H
@@ -34,7 +34,11 @@
 #include <sys/socket.h>
 #endif
 
+#ifdef PHP_WIN32
+#include <win32/php_stdint.h>
+#else
 #include <stdint.h>
+#endif
 #include <string.h>
 
 #include "php.h"
